@@ -26,7 +26,7 @@ rm -f handshake.txt $networklist replay*.cap arp-request.cap replay_dec*.xor rep
 
 #unload the drivers
 cd $driverdir
-sudo sh unload.sh >>/dev/null 2>&1
+sudo ./unload.sh >>/dev/null 2>&1
 sleep 2
 
 exit
